<template>
    <div class="dialog-table-container sub-page-inner">
        <div class="sub-table-container">
            <el-table
                :element-loading-background="loadingColor"
                v-loading="loading"
                height="calc(100% - 120px)"
                align="center"
                :data="tableData"
                class="dialog_table"
                :cell-style="{'text-align': 'center'}"
                :header-cell-style="{'text-align': 'center'}"
                ref="myTable"
                highlight-current-row
                @current-change="currentChange"
            >
                <el-table-column type="index" label="序号" width="50">
                </el-table-column>
                <el-table-column
                    prop="projectName"
                    label="项目名称"
                    width="320"
                >
                </el-table-column>
                <el-table-column prop="updateNum" label="迭代举措数">
                </el-table-column>
                <el-table-column prop="addNum" label="新增举措数">
                </el-table-column>
                <el-table-column prop="iterationSn" label="排位">
                </el-table-column>
            </el-table>
            <!-- <pagenation @currentChange="pageChange" class="pagenation"></pagenation> -->
        </div>
        <div class="sub-page-detail">
            <el-table
                v-loading="infoLoading"
                :element-loading-background="loadingColor"
                class="dialog_table"
                :data="infoTableData"
                style="width: 100%"
            >
                <el-table-column
                    type="index"
                    label="序号"
                    width="50"
                    align="center"
                >
                </el-table-column>
                <el-table-column prop="oldName" label="原举措" align="center">
                    <template v-slot="{row}">
                        {{ row.oldName || '----' }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="newName"
                    label="迭代后举措"
                    align="center"
                >
                </el-table-column>
                <el-table-column prop="cause" label="迭代依据" align="center">
                    <template v-slot="{row}">
                        {{ row.cause || '----' }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="iterType"
                    label="迭代类型"
                    align="center"
                >
                </el-table-column>
                <el-table-column prop="time" label="迭代时间" align="center">
                </el-table-column>
            </el-table>
        </div>
    </div>
</template>

<script>
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/majorView.js'
import moment from 'moment'
export default {
    name: 'iterationList',
    components: {pagenation},
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [],
            infoTableData: [],
            iterLoading: false,
            infoLoading: false,
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.$emit('searchDateChange')
        this.getProjectBrand()
        this.$bus.$on('changeDate', (searchDate) => {
            this.getProjectBrand()
        })
    },
    methods: {
        currentChange(currentRow, oldCurrentRow) {
            this.handleDetail(currentRow)
        },
        handleDetail(row) {
            this.infoLoading = true
            apiList.getIterationList(row.projectId, (res) => {
                if (res) {
                    res.iterationAddVO.forEach((item) => {
                        item.iterType = '新增举措'
                        item.newName = item.name
                        item.time = moment(item.time).format('YYYY-MM-DD')
                    })
                    res.iterationUpdateVO.forEach((item) => {
                        item.iterType = '迭代举措'
                        item.time = moment(item.time).format('YYYY-MM-DD')
                    })
                    this.infoTableData = [
                        ...res.iterationUpdateVO,
                        ...res.iterationAddVO,
                    ]
                    this.iterLoading = false
                }
                this.infoLoading = false
            })
        },
        // 迭代榜
        getProjectBrand() {
            this.loading = true
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            let data = {
                year: searchDate.year,
                month: searchDate.month,
            }
            apiList.getIteration(data, (res) => {
                if (res) {
                    this.tableData = res
                    this.$nextTick(() => {
                        this.$refs.myTable.setCurrentRow(
                            this.$refs.myTable.data[0]
                        )
                    })
                }
                this.loading = false
            })
        },
    },
}
</script>
<style lang="scss" scoped>
.infoTable {
  margin: -12px 0;
  //   min-height: 78px;
  /*最外层透明*/
  /deep/ .el-table,
  /deep/ .el-table__expanded-cell {
    background-color: transparent;
  }
  /* 表格内背景颜色 */
  /deep/ .el-table th,
  /deep/ .el-table tr,
  /deep/ .el-table td {
    background-color: rgba(2, 62, 141, 1);
  }
  /deep/.el-table::before {
    left: 0;
    bottom: 0;
    width: 100%;
    height: 0px;
  }
  .el-table__cell {
    padding: 0;
  }
}
/deep/.el-table__expand-column .cell {
  width: 0;
  height: 0;
  display: none;
}
.box-card {
  flex: 1;
  width: 100%;
  background-color: #032f79;
  border: 1px dashed #3a79e6;
  color: #fff;
  margin-bottom: 10px;
  .jc-item {
    margin-bottom: 4px;
    font-family: SimHei;
  }
}
.jc-title {
  font-size: 16px;
  font-family: SimHei;
  font-weight: 400;
  color: #fff;
  margin: 20px 0 10px;
}
.flex-space-a {
  display: flex;
  justify-content: space-around;
  align-items: center;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
